==> python-anilist-1.0.5.tar.gz: python-anilist-1.0.5/README.md <==
<!--
  ~ Copyright (C) 2021 Amano Team <https://amanoteam.com/>, nfitzen
  ~ 
  ~ SPDX-License-Identifier: MIT
  -->

# python-anilist

[![License](https://img.shields.io/github/license/AmanoTeam/aiodown)](https://github.com/AmanoTeam/python-anilist/raw/main/LICENSE)
![Tests](https://github.com/mCodingLLC/SlapThatLikeButton-TestingStarterProject/actions/workflows/tests.yml/badge.svg)
![Code style](https://img.shields.io/badge/code%20style-black-000000.svg)
[![Contributors](https://img.shields.io/github/contributors/AmanoTeam/python-anilist.svg)](https://github.com/AmanoTeam/python-anilist/graphs/contributors)
[![PyPi](https://badge.fury.io/py/python-anilist.svg)](https://pypi.org/project/python-anilist/)

> A simple wrapper with full support for `asyncio` made in `Python 3` for [Anilist](//anilist.co) using [httpx](//github.com/encode/httpx).

## Requirements

- Python 3.6 or higher.
- httpx 0.14 or higher.

## Installation

**NOTE:** If `python3` is "not a recognized command" try using `python` instead.

For the latest stable version:<br>
```
python3 -m pip install python-anilist
```

For the latest development version:<br>
```
python3 -m pip install git+https://github.com/0x16c3/python-anilist.git#egg=python-anilist
```

## What's left to do?

- Write the API Documentation.
- Add support for more types of content.
- Show some examples.

## Credits

* [AnilistPy](//github.com/anilistpy/anilistpy): for inspiration.

## License

Copyright © 2021 [AmanoTeam](https://github.com/AmanoTeam)

Licensed under the [Expat/MIT license](LICENSE).
This project is also [REUSE compliant](https://reuse.software/).
See individual files for more copyright information.

==> python-anilist-1.0.9.tar.gz: python-anilist-1.0.9/README.md <==
<!--
  ~ Copyright (C) 2021-2022 Amano Team <https://amanoteam.com/>, nfitzen
  ~ 
  ~ SPDX-License-Identifier: MIT
  -->

# python-anilist

[![License](https://img.shields.io/github/license/AmanoTeam/aiodown)](https://github.com/AmanoTeam/python-anilist/raw/main/LICENSE)
![Tests](https://github.com/mCodingLLC/SlapThatLikeButton-TestingStarterProject/actions/workflows/tests.yml/badge.svg)
![Code style](https://img.shields.io/badge/code%20style-black-000000.svg)
[![Contributors](https://img.shields.io/github/contributors/AmanoTeam/python-anilist.svg)](https://github.com/AmanoTeam/python-anilist/graphs/contributors)
[![PyPi](https://badge.fury.io/py/python-anilist.svg)](https://pypi.org/project/python-anilist/)

> A simple wrapper with full support for `asyncio` made in `Python 3` for [Anilist](//anilist.co) using [httpx](//github.com/encode/httpx).

## Requirements

- Python 3.7 or higher.
- httpx 0.14 or higher.

## Installation

**NOTE:** If `python3` is "not a recognized command" try using `python` instead.

For the latest stable version:
```sh
python3 -m pip install python-anilist
```

For the latest development version:
```sh
python3 -m pip install git+https://github.com/AmanoTeam/python-anilist.git#egg=python-anilist
```

## What's left to do?

- Write the API Documentation.
- Show some examples.

## Credits

* [AnilistPy](//github.com/anilistpy/anilistpy): for inspiration.

## License

Copyright © 2021-2022 [AmanoTeam](https://github.com/AmanoTeam)
and the python-anilist contributors

Licensed under the [Expat/MIT license](LICENSE).
This project is also [REUSE compliant](https://reuse.software/).
See individual files for more copyright information.
